clear
clear all
clear matrix
set mem 200m
set matsize 5000
set more off

cd "C:\..." /*Change directory to one containing the dataset*/
use diseaseJPE.dta

/*Create life expectancy in 1900 to be used as an additional control*/
gen temp=.
replace temp=loglifeexpect if year==1900
bysort ctry: egen LE1900=mean(temp)
drop temp


/*Create GDP per capita in 1940 to be used as an additional control*/
gen temp=.
replace temp=loggdppcmadd if year==1940
bysort ctry: egen GDP1940=mean(temp)
drop temp

/*Keep countries in balanced panel sample*/
keep if (sample40==1 & sample80==1) &sjbasesamplenoncomm==1

/*Year dummies from yy1 (1930) to yy8 (2000)*/
quietly: tab year, gen(yy) 
xtset ctry year, delta(10)

/*Create variables used in the empirical analysis*/
gen yvar=loggdppcmadd /*Variable of interest*/
gen lyvar=L.yvar

/*GDP in 1940 time year effects*/
gen trend_gdp1=GDP1940*yy1
gen trend_gdp2=GDP1940*yy2
gen trend_gdp3=GDP1940*yy3
gen trend_gdp4=GDP1940*yy4
gen trend_gdp5=GDP1940*yy5
gen trend_gdp6=GDP1940*yy6
gen trend_gdp7=GDP1940*yy7
gen trend_gdp8=GDP1940*yy8

/*GDP in 1940 time year effects*/
gen trend_le1=LE1900*yy1
gen trend_le2=LE1900*yy2
gen trend_le3=LE1900*yy3
gen trend_le4=LE1900*yy4
gen trend_le5=LE1900*yy5
gen trend_le6=LE1900*yy6
gen trend_le7=LE1900*yy7
gen trend_le8=LE1900*yy8

/**************************************/
**********TOP PANEL, 1940-1980**********
*Notes:
*The coefficient on loglifeexpect corresponds to the effect of life expectancy.
*The coefficient on lyvar1940 corresponds to lagged GDP per capita.
*The dependent variable is the log of GDP per capita. 
/**************************************/

/*Column 1, simple 2SLS instrumenting life expectancy without differential trends*/
xtivreg2 yvar (loglifeexpect=compsjmhatit) yy3-yy6  if year>1930&year<1990, fe cluster(ctry) robust

/*Column 2, simple 2SLS instrumenting life expectancy*/
xtivreg2 yvar (loglifeexpect=compsjmhatit) yy3-yy6 trend_le1-trend_le8 if year>1930&year<1990, fe cluster(ctry) robust

/*Column 3, simple 2SLS instrumenting life expectancy, controlling for GDP per capita in 1900 interacted with year effects*/
xtivreg2 yvar (loglifeexpect=compsjmhatit) yy3-yy6 trend_gdp1-trend_gdp8 trend_le1-trend_le8 if year>1930&year<1990, fe cluster(ctry) robust

/*Column 4, simple 2SLS instrumenting life expectancy, includes lagged GDP. Also uses 1940 since GDP per capita is available for 1930*/
xtivreg2 yvar lyvar (loglifeexpect=compsjmhatit) yy3-yy6 trend_le1-trend_le8 if year>1930&year<1990, fe cluster(ctry) robust

/*Column 5, arellano bond estimates using all internal lags as instruments*/
xtabond2 yvar lyvar  loglifeexpect yy3-yy6 trend_le1-trend_le8 if year>1930&year<1990, gmmstyle(yvar, laglimits(2 .)) gmmstyle(compsjmhatit, laglimits(1 .)) ivstyle(yy3-yy6 trend_le1-trend_le8,p) noleveleq robust twostep



/*****************************************/
**********BOTTOM PANEL, 1940-2000**********
*Notes:
*The coefficient on loglifeexpect corresponds to the effect of life expectancy.
*The coefficient on lyvar1940 corresponds to lagged GDP per capita.
*The dependent variable is the log of GDP per capita. 
/*****************************************/

/*Column 1, simple 2SLS instrumenting life expectancy without differential trends*/
xtivreg2 yvar (loglifeexpect=compsjmhatit) yy3-yy8  if year>1930, fe cluster(ctry) robust

/*Column 2, simple 2SLS instrumenting life expectancy*/
xtivreg2 yvar (loglifeexpect=compsjmhatit) yy3-yy8 trend_le1-trend_le8 if year>1930, fe cluster(ctry) robust

/*Column 3, simple 2SLS instrumenting life expectancy, controlling for GDP per capita in 1900 interacted with year effects*/
xtivreg2 yvar (loglifeexpect=compsjmhatit) yy3-yy8 trend_gdp1-trend_gdp8  trend_le1-trend_le8 if year>1930, fe cluster(ctry) robust

/*Column 4, simple 2SLS instrumenting life expectancy, includes lagged GDP. Also uses 1940 since GDP per capita is available for 1930*/
xtivreg2 yvar lyvar (loglifeexpect=compsjmhatit) yy3-yy8  trend_le1-trend_le8 if year>1930, fe cluster(ctry) robust

/*Column 5, arellano bond estimates using all intarnal lags as instruments*/
xtabond2 yvar lyvar  loglifeexpect yy3-yy8  trend_le1-trend_le8 if year>1930, gmmstyle(yvar, laglimits(2 .)) gmmstyle(compsjmhatit, laglimits(1 .)) ivstyle(yy3-yy8  trend_le1-trend_le8, p) noleveleq robust twostep



