clear
clear all
clear matrix
set mem 200m
set matsize 5000
set more off

cd "C:\..." /*Change directory to one containing the dataset. The file samples.dat should be in the same folder.*/
use diseaseJPE.dta

/*Create dependent variable*/
gen yvar=loggdppcmadd

/*Keep countries in balanced panel sample and reshape it to wide*/
keep ctry year  yvar loglifeexpect compsjmhatit 
drop if year==.

reshape wide yvar loglifeexpect compsjmhatit, i(ctry) j(year)
sort ctry

/*Merge variables indicating countries in balanced sample*/
merge ctry using samples.dta
drop _merge

/*Keep countries in balanced sample*/
keep if  (sample40==1 & sample80==1) &sjbasesamplenoncomm==1

/**************************************/
**********TOP PANEL, 1940-1980**********
/**************************************/
*Notes:
*The coefficient on longLE corresponds to the effect of life expectancy.
*The coefficient on yvar1940 corresponds to GDP per capita in 1940.
*The dependent variable is the long difference in GDP per capita minus kappa*life expectancy in 1940. 
/**************************************/

/*Create long differences*/
gen longyvar=yvar1980-yvar1940 
gen longLE=loglifeexpect1980-loglifeexpect1940 /*Long difference in life expectancy*/
gen longPM=compsjmhatit1980-compsjmhatit1940 /*Long difference in instrument*/


local kappa=0.3 /*Columns 1 and 2, set kappa=0.3*/
gen dep=longyvar-`kappa'*loglifeexpect1940
ivreg2 dep (longLE=longPM), robust
ivreg2 dep (longLE=longPM) yvar1940, robust
drop dep

local kappa=0.4 /*Columns 3 and 4, set kappa=0.3*/
gen dep=longyvar-`kappa'*loglifeexpect1940
ivreg2 dep (longLE=longPM), robust
ivreg2 dep (longLE=longPM) yvar1940, robust
drop dep

local kappa=0.5 /*Columns 5 and 6, set kappa=0.3*/
gen dep=longyvar-`kappa'*loglifeexpect1940
ivreg2 dep (longLE=longPM), robust
ivreg2 dep (longLE=longPM) yvar1940, robust
drop dep

local kappa=0.6 /*Columns 7 and 8, set kappa=0.3*/
gen dep=longyvar-`kappa'*loglifeexpect1940
ivreg2 dep (longLE=longPM), robust
ivreg2 dep (longLE=longPM) yvar1940, robust
drop dep

drop longyvar longLE longPM

/*****************************************/
**********BOTTOM PANEL, 1940-2000**********
*Notes:
*The coefficient on longLE corresponds to the effect of life expectancy.
*The coefficient on yvar1940 corresponds to GDP per capita in 1940.
*The dependent variable is the long difference in GDP per capita minus kappa*life expectancy in 1940. 
/*****************************************/

/*Create long differences*/
gen longyvar=yvar2000-yvar1940
gen longLE=loglifeexpect2000-loglifeexpect1940
gen longPM=compsjmhatit2000-compsjmhatit1940

local kappa=0.3 /*Columns 1 and 2, set kappa=0.3*/
gen dep=longyvar-`kappa'*loglifeexpect1940
ivreg2 dep (longLE=longPM), robust
ivreg2 dep (longLE=longPM) yvar1940, robust
drop dep

local kappa=0.4 /*Columns 3 and 4, set kappa=0.3*/
gen dep=longyvar-`kappa'*loglifeexpect1940
ivreg2 dep (longLE=longPM), robust
ivreg2 dep (longLE=longPM) yvar1940, robust
drop dep

local kappa=0.5 /*Columns 5 and 6, set kappa=0.3*/
gen dep=longyvar-`kappa'*loglifeexpect1940
ivreg2 dep (longLE=longPM), robust
ivreg2 dep (longLE=longPM) yvar1940, robust
drop dep

local kappa=0.6 /*Columns 7 and 8, set kappa=0.3*/
gen dep=longyvar-`kappa'*loglifeexpect1940
ivreg2 dep (longLE=longPM), robust
ivreg2 dep (longLE=longPM) yvar1940, robust
drop dep

drop longyvar longLE longPM
